/* See LICENSE file for copyright and license details. */

/* appearance */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const unsigned int snap      = 16;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "VGA" };
static const char *colors[][3]      = {
	/*               fg         bg         border   */
	[SchemeNorm] = { "#dddddd", "#000055", "#555555" },
	[SchemeSel] =  { "#dddddd", "#5555ff", "#ff0000" },
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", "0" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title       tags mask     isfloating   monitor */
	{ NULL,       "xrun",     NULL,       0,            1,           -1 },
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

void better(Monitor *m) {
	unsigned int x, y, x0, y0, w, h, n, p, k, b;
	Client *c;
	x = y = 0;
	x0 = m->wx;
	y0 = m->wy;
	w = m->ww;
	h = m->wh;
	for (n = 0, c = nexttiled(m->clients); c; c = nexttiled(c->next), n++);
	p = MIN(n, w / 768);
	for (k = 0, c = nexttiled(m->clients); c; c = nexttiled(c->next), k++) {
		b = c->bw;
		if (k < p-1) {
			resize(c, x0+x, y0+y, (w-x)/(p-k)-2*b, h-2*b, 0);
			x += WIDTH(c);
		} else {
			resize(c, x0+x, y0+y, (w-x)-2*b, (h-y)/(n-k)-2*b, 0);
			y += HEIGHT(c);
		}
	}
}

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[#]", better },
	{ "[0]", monocle },
};

void moview(const Arg *arg) {
	unsigned int *s = selmon->tagset+selmon->seltags;
	unsigned int n = LENGTH(tags)-1;
	if (arg->i<0) *s>>=1;
	if (arg->i>0) *s<<=1;
	if (*s>1<<n) *s=1;
	if (*s<1) *s=1<<n;
	focus(NULL);
	arrange(selmon);
}

#include <X11/XF86keysym.h>

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "to be optimized out" };

static const char *x_scr_up[] = { "xbacklight", "-inc", "7", NULL };
static const char *x_scr_dn[] = { "xbacklight", "-dec", "7", NULL };
static const char *x_snd_up[] = { "xsound", "+3", NULL };
static const char *x_snd_dn[] = { "xsound", "-3", NULL };
static const char *x_snd_no[] = { "xsound", "mute", NULL };

static const char *x_lck[] = { "slock", NULL };
static const char *x_tty[] = { "xterm", NULL };
static const char *x_eml[] = { "xterm", "-e", "screen", "-c", "/dev/null", "-DRRS", "mutt", "mutt", NULL };
static const char *x_run[] = { "xrun", NULL };
static const char *x_web[] = { "xrun", "xweb", NULL };
static const char *x_url[] = { "xurl", NULL };

static const Key keys[] = {
	/* modifier                     key        function        argument */
	{ 0,                     XF86XK_MonBrightnessUp,   spawn,          { .v=x_scr_up } },
	{ 0,                     XF86XK_MonBrightnessDown, spawn,          { .v=x_scr_dn } },
	{ 0,                     XF86XK_AudioRaiseVolume,  spawn,          { .v=x_snd_up } },
	{ 0,                     XF86XK_AudioLowerVolume,  spawn,          { .v=x_snd_dn } },
	{ 0,                     XF86XK_AudioMute,         spawn,          { .v=x_snd_no } },
	{ 0,                     XK_Pause,                 spawn,          { .v=x_lck    } },
	{ 0,                     XK_Print,                 spawn,          { .v=x_lck    } },
	{ Mod4Mask,              XK_bracketright,          spawn,          { .v=x_scr_up } },
	{ Mod4Mask,              XK_backslash,             spawn,          { .v=x_scr_dn } },
	{ Mod4Mask,              XK_bracketleft,           spawn,          { .v=x_snd_up } },
	{ Mod4Mask,              XK_apostrophe,            spawn,          { .v=x_snd_dn } },
	{ Mod4Mask,              XK_e,                     spawn,          { .v=x_tty    } },
	{ Mod4Mask,              XK_m,                     spawn,          { .v=x_eml    } },
	{ Mod4Mask,              XK_r,                     spawn,          { .v=x_run    } },
	{ Mod4Mask,              XK_u,                     spawn,          { .v=x_url    } },
	{ Mod4Mask,              XK_w,                     spawn,          { .v=x_web    } },
	{ Mod4Mask|ShiftMask,    XK_q,                     quit,           { 0           } },
	{ Mod4Mask,              XK_b,                     togglebar,      { 0           } },
	{ Mod4Mask,              XK_q,                     killclient,     { 0           } },
	{ Mod4Mask,              XK_a,                     togglefloating, { 0           } },
	{ Mod4Mask,              XK_Return,                zoom,           { 0           } },
	{ Mod4Mask,              XK_x,                     setlayout,      { 0           } },
	{ Mod4Mask,              XK_Up,                    focusstack,     { .i=-1       } },
	{ Mod4Mask,              XK_Down,                  focusstack,     { .i=+1       } },
	{ Mod4Mask,              XK_Left,                  moview,         { .i=-1       } },
	{ Mod4Mask,              XK_Right,                 moview,         { .i=+1       } },
	{ Mod4Mask,              XK_Tab,                   view,           { 0           } },
	{ Mod4Mask,              XK_1,                     view,           { .ui=1<<0    } },
	{ Mod4Mask,              XK_2,                     view,           { .ui=1<<1    } },
	{ Mod4Mask,              XK_3,                     view,           { .ui=1<<2    } },
	{ Mod4Mask,              XK_4,                     view,           { .ui=1<<3    } },
	{ Mod4Mask,              XK_5,                     view,           { .ui=1<<4    } },
	{ Mod4Mask,              XK_6,                     view,           { .ui=1<<5    } },
	{ Mod4Mask,              XK_7,                     view,           { .ui=1<<6    } },
	{ Mod4Mask,              XK_8,                     view,           { .ui=1<<7    } },
	{ Mod4Mask,              XK_9,                     view,           { .ui=1<<8    } },
	{ Mod4Mask,              XK_0,                     view,           { .ui=1<<9    } },
	{ ControlMask,           XK_1,                     tag,            { .ui=1<<0    } },
	{ ControlMask,           XK_2,                     tag,            { .ui=1<<1    } },
	{ ControlMask,           XK_3,                     tag,            { .ui=1<<2    } },
	{ ControlMask,           XK_4,                     tag,            { .ui=1<<3    } },
	{ ControlMask,           XK_5,                     tag,            { .ui=1<<4    } },
	{ ControlMask,           XK_6,                     tag,            { .ui=1<<5    } },
	{ ControlMask,           XK_7,                     tag,            { .ui=1<<6    } },
	{ ControlMask,           XK_8,                     tag,            { .ui=1<<7    } },
	{ ControlMask,           XK_9,                     tag,            { .ui=1<<8    } },
	{ ControlMask,           XK_0,                     tag,            { .ui=1<<9    } },
	{ Mod4Mask|ShiftMask,    XK_Left,                  focusmon,       { .i=-1       } },
	{ Mod4Mask|ShiftMask,    XK_Right,                 focusmon,       { .i=+1       } },
	{ ControlMask|ShiftMask, XK_Left,                  tagmon,         { .i=-1       } },
	{ ControlMask|ShiftMask, XK_Right,                 tagmon,         { .i=+1       } },
};

/* button definitions */
/* click can be ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkClientWin, Mod4Mask,             Button1, movemouse,   {0} },
	{ ClkClientWin, Mod4Mask|ControlMask, Button1, resizemouse, {0} },
};
